import { ViteHotContext } from 'vite-hot-client';
import { V as ViteRPCFunctions, A as AssetInfo, I as ImageMeta, M as ModuleInfo } from './types-1TEmpkcj.js';
export { b as AssetEntry, a as AssetType, C as CodeSnippet } from './types-1TEmpkcj.js';
import { ComponentHighLighterOptions, ScrollToComponentOptions, InspectorStateEditorPayload, AppRecord, CustomTab, CustomCommand, InspectorNodeTag, InspectorState, RouterInfo, TimelineEvent, OpenInEditorOptions } from '@vue/devtools-kit';
import * as mitt from 'mitt';
import { EventType, Handler } from 'mitt';
import { Plugin, Ref } from 'vue';
import { BirpcReturn, BirpcGroupReturn } from 'birpc';
import { WebSocketServer } from 'vite';

interface BridgeAdapterOptions {
    tracker: (fn: Function) => void;
    trigger: (data: Record<string, any>) => void;
}
type BridgeInstanceType = InstanceType<typeof Bridge>;
declare class Bridge<Events extends Record<EventType, any>, Key extends keyof Events> {
    private emitter;
    private adapter;
    constructor(adapter?: BridgeAdapterOptions);
    private _on;
    private off;
    private _emit;
    on(eventName: Key, handler: Handler<Events[Key]>): () => void;
    once(eventName: Key, handler: Handler<Events[Key]>): void;
    emit(eventName: Key, data?: any): void;
    removeAllListeners(): void;
}
declare const bridgeRpcEvents: {
    readonly toggleComponentInspector: "toggle-component-inspector";
    readonly inspectComponentInspector: "inspect-component-inspector";
    readonly scrollToComponent: "scroll-to-component";
    readonly componentBoundingRect: "component-bounding-rect";
    readonly inspectorTree: "inspector-tree";
    readonly inspectorState: "inspector-state";
    readonly updateInspectorTreeId: "inspector-tree:update-id";
    readonly state: "state";
    readonly timelineLayer: "timeline-layer";
    readonly routerInfo: "router-info";
    readonly router: "router";
    readonly routeMatched: "route-matched";
    readonly editState: "edit-inspector-state";
    readonly openInEditor: "open-in-editor";
    readonly toggleApp: "toggle-app";
    readonly isVueInspectorDetected: "vue-inspector:detected";
    readonly enableVueInspector: "vue-inspector:enable";
    readonly unhighlightElement: "element:unhighlight";
};
interface BridgeRpcEventPayload {
    [bridgeRpcEvents.toggleComponentInspector]: ComponentHighLighterOptions;
    [bridgeRpcEvents.scrollToComponent]: ScrollToComponentOptions;
    [bridgeRpcEvents.inspectComponentInspector]: string;
    [bridgeRpcEvents.componentBoundingRect]: {
        inspectorId: string;
        instanceId: string;
    };
    [bridgeRpcEvents.inspectorTree]: {
        inspectorId?: string;
        filter?: string;
    };
    [bridgeRpcEvents.updateInspectorTreeId]: string;
    [bridgeRpcEvents.inspectorState]: {
        inspectorId: string;
        nodeId: string;
    };
    [bridgeRpcEvents.state]: null;
    [bridgeRpcEvents.timelineLayer]: null;
    [bridgeRpcEvents.routerInfo]: null;
    [bridgeRpcEvents.router]: string;
    [bridgeRpcEvents.routeMatched]: string;
    [bridgeRpcEvents.editState]: InspectorStateEditorPayload;
    [bridgeRpcEvents.openInEditor]: string;
    [bridgeRpcEvents.toggleApp]: string;
    [bridgeRpcEvents.isVueInspectorDetected]: boolean;
    [bridgeRpcEvents.enableVueInspector]: null;
    [bridgeRpcEvents.unhighlightElement]: null;
}

interface SetupViteRPCClientOptions {
    moduleUpdated?: () => void;
    assetsUpdated?: () => void;
}
declare function setupViteRPCClient(ctx: ViteHotContext | undefined, options?: SetupViteRPCClientOptions): BirpcReturn<ViteRPCFunctions, unknown>;

declare function setupViteRPCServer(ws: WebSocketServer, functions: ViteRPCFunctions): BirpcGroupReturn<ViteRPCFunctions>;

interface DevToolsPluginOptions {
    bridge: BridgeInstanceType;
    viewMode: 'overlay' | 'panel';
}
type DevtoolsBridgeAppRecord = Pick<AppRecord, 'name' | 'id' | 'version' | 'routerId' | 'moduleDetectives'>;
declare function createDevToolsVuePlugin(pluginOptions: DevToolsPluginOptions): Plugin;
declare function useDevToolsBridge(): Ref<Bridge<Record<mitt.EventType, any>, mitt.EventType>>;
declare function useDevToolsBridgeRpc(): typeof BridgeRpc$1;
declare function useDevToolsState(): {
    connected: Ref<boolean>;
    clientConnected: Ref<boolean>;
    componentCount: Ref<number>;
    vueVersion: Ref<string>;
    tabs: Ref<CustomTab[]>;
    commands: Ref<CustomCommand[]>;
    vitePluginDetected: Ref<boolean>;
    appRecords: Ref<DevtoolsBridgeAppRecord[]>;
    activeAppRecordId: Ref<string>;
};

interface BridgeRpcOptions {
    viteRPCContext?: ViteHotContext | undefined;
    bridge: BridgeInstanceType;
}
declare class BridgeRpc$1 {
    static on: {
        inspectorTreeUpdated<T = {
            inspectorId: string;
            data: {
                id: string;
                label: string;
                tags: InspectorNodeTag[];
            }[];
        }>(cb: (payload: T) => void, options: {
            inspectorId: string;
        }): void;
        inspectorStateUpdated<T_1 = {
            inspectorId: string;
            state: InspectorState[];
        }>(cb: (payload: T_1) => void, options: {
            inspectorId: string;
        }): void;
        devtoolsStateUpdated(cb: any): void;
        customTabsUpdated(cb: (payload: CustomTab[]) => void): void;
        customCommandsUpdated(cb: (payload: CustomCommand[]) => void): void;
        routerInfoUpdated(cb: (payload: RouterInfo) => void): void;
        addTimelineEvent(cb: (payload: TimelineEvent) => void): void;
    };
    static updateInspectorTreeId(id: string): void;
    static toggleComponentInspector(payload: BridgeRpcEventPayload['toggle-component-inspector']): void;
    static inspectComponentInspector(): Promise<{
        data: {
            id: string;
        };
    }>;
    static unhighlightElement(): Promise<unknown>;
    static scrollToComponent(payload: BridgeRpcEventPayload['scroll-to-component']): Promise<unknown>;
    static getComponentBoundingRect<R extends {
        data: unknown;
    } = {
        data: {
            top: number;
            left: number;
            width: number;
            height: number;
        };
    }>(payload: BridgeRpcEventPayload['component-bounding-rect']): Promise<R>;
    static getInspectorTree<R extends {
        data: unknown[];
    } = {
        data: {
            id: string;
            label: string;
            tags: InspectorNodeTag[];
        }[];
    }>(payload: BridgeRpcEventPayload['inspector-tree']): Promise<R>;
    static getInspectorState<R extends {
        data: unknown;
    } = {
        data: {
            state: InspectorState[];
        };
    }>(payload: BridgeRpcEventPayload['inspector-state']): Promise<R>;
    static editInspectorState<R extends {
        data: unknown;
    } = {
        data: {
            state: InspectorState[];
        };
    }>(payload: BridgeRpcEventPayload['edit-inspector-state']): Promise<R>;
    static getDevToolsState(): Promise<{
        data: {
            connected: boolean;
            clientConnected: boolean;
            vueVersion: string;
            tabs: CustomTab[];
            commands: CustomCommand[];
            vitePluginDetected: boolean;
            appRecords: Array<DevtoolsBridgeAppRecord>;
            activeAppRecordId: string;
        };
    }>;
    static getTimelineLayer(): Promise<{
        data: {
            id: string;
            label: string;
            color: number;
        }[];
    }>;
    static getRouterInfo(): Promise<{
        data: RouterInfo;
    }>;
    static navigate(payload: Record<string, string>): Promise<void>;
    static getMatchedRoutes(path: string): Promise<{
        data: {
            path: string;
        }[];
    }>;
    static openInEditor(payload: OpenInEditorOptions): Promise<void>;
    static isVueInspectorDetected(): Promise<{
        data: boolean;
    }>;
    static enableVueInspector(): Promise<void>;
    static toggleApp(id: string): Promise<void>;
    static getStaticAssets(): Promise<AssetInfo[]>;
    static getImageMeta(filepath: string): Promise<ImageMeta | undefined>;
    static getTextAssetContent(filepath: string, limit?: number): Promise<string | undefined>;
    static root(): Promise<string>;
    static getGraph(): Promise<ModuleInfo[]>;
    static graphModuleUpdated(fn: Function): () => void;
    static assetsUpdated(fn: Function): () => void;
}

declare class BridgeRpc {
}

declare enum BridgeEvents {
    DEVTOOLS_STATE_UPDATED = "devtools-state:updated",
    CUSTOM_TABS_UPDATED = "custom-tabs:updated",
    CUSTOM_COMMANDS_UPDATED = "custom-commands:updated",
    ROUTER_INFO_UPDATED = "router-info:updated",
    ROUTER = "router",
    APP_CONNECTED = "user-app:connected",
    CLIENT_READY = "devtools:client-ready",
    SEND_INSPECTOR_TREE = "inspector-tree:send",
    SEND_INSPECTOR_STATE = "inspector-state:send",
    EDIT_STATE = "state:edit",
    ADD_TIMELINE_EVENT = "timeline:add-event"
}

declare function registerBridgeRpc(target: 'devtools' | 'user-app', options: BridgeRpcOptions): void;

declare function prepareInjection(bridge: BridgeInstanceType): void;

declare enum HandShakeEvents {
    SYN = "syn",
    SYN_ACK = "syn-ack",
    ACK = "ack"
}
declare class HandShake {
    socket: BridgeInstanceType;
    constructor(bridge: BridgeInstanceType);
}
declare class HandShakeClient extends HandShake {
    constructor(bridge: BridgeInstanceType);
    onnConnect(): Promise<void>;
}
declare class HandShakeServer extends HandShake {
    constructor(bridge: BridgeInstanceType);
    onnConnect(): Promise<void>;
}

declare function setDevToolsClientUrl(url: string): void;
declare function getDevToolsClientUrl(): any;

export { AssetInfo, Bridge, BridgeEvents, type BridgeInstanceType, type DevToolsPluginOptions, BridgeRpc$1 as DevToolsRpc, type DevtoolsBridgeAppRecord, HandShakeClient, HandShakeEvents, HandShakeServer, ImageMeta, ModuleInfo, type SetupViteRPCClientOptions, BridgeRpc as UserAppRpc, ViteRPCFunctions, createDevToolsVuePlugin, getDevToolsClientUrl, prepareInjection, registerBridgeRpc, setDevToolsClientUrl, setupViteRPCClient, setupViteRPCServer, useDevToolsBridge, useDevToolsBridgeRpc, useDevToolsState };
