"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/server/index.ts
var server_exports = {};
__export(server_exports, {
  setupAssetsRPC: () => setupAssetsRPC,
  setupGraphRPC: () => setupGraphRPC
});
module.exports = __toCommonJS(server_exports);

// src/vite-rpc/assets.ts
var import_promises = __toESM(require("fs/promises"), 1);
var import_fast_glob = __toESM(require("fast-glob"), 1);
var import_pathe = require("pathe");
var import_image_meta = require("image-meta");
var import_perfect_debounce = require("perfect-debounce");
var defaultAllowedExtensions = [
  "png",
  "jpg",
  "jpeg",
  "gif",
  "svg",
  "webp",
  "ico",
  "mp4",
  "ogg",
  "mp3",
  "wav",
  "mov",
  "mkv",
  "mpg",
  "txt",
  "ttf",
  "woff",
  "woff2",
  "eot",
  "json",
  "js",
  "jsx",
  "ts",
  "tsx",
  "md",
  "mdx",
  "vue",
  "webm"
];
function guessType(path) {
  if (/\.(png|jpe?g|jxl|gif|svg|webp|avif|ico|bmp|tiff?)$/i.test(path))
    return "image";
  if (/\.(mp4|webm|ogv|mov|avi|flv|wmv|mpg|mpeg|mkv|3gp|3g2|ts|mts|m2ts|vob|ogm|ogx|rm|rmvb|asf|amv|divx|m4v|svi|viv|f4v|f4p|f4a|f4b)$/i.test(path))
    return "video";
  if (/\.(mp3|wav|ogg|flac|aac|wma|alac|ape|ac3|dts|tta|opus|amr|aiff|au|mid|midi|ra|rm|wv|weba|dss|spx|vox|tak|dsf|dff|dsd|cda)$/i.test(path))
    return "audio";
  if (/\.(woff2?|eot|ttf|otf|ttc|pfa|pfb|pfm|afm)/i.test(path))
    return "font";
  if (/\.(json[5c]?|te?xt|[mc]?[jt]sx?|md[cx]?|markdown|ya?ml|toml)/i.test(path))
    return "text";
  return "other";
}
function setupAssetsRPC(config) {
  const server = config.server;
  const getRpcServer = config.getRpcServer;
  const _imageMetaCache = /* @__PURE__ */ new Map();
  let cache = null;
  const extensions = defaultAllowedExtensions;
  async function scan() {
    const dir = (0, import_pathe.resolve)(config.root);
    const baseURL = config.base;
    const files = await (0, import_fast_glob.default)([
      // image
      "**/*.(png|jpg|jpeg|gif|svg|webp|avif|ico|bmp|tiff)",
      // video
      "**/*.(mp4|webm|ogv|mov|avi|flv|wmv|mpg|mpeg|mkv|3gp|3g2|m2ts|vob|ogm|ogx|rm|rmvb|asf|amv|divx|m4v|svi|viv|f4v|f4p|f4a|f4b)",
      // audio
      "**/*.(mp3|wav|ogg|flac|aac|wma|alac|ape|ac3|dts|tta|opus|amr|aiff|au|mid|midi|ra|rm|wv|weba|dss|spx|vox|tak|dsf|dff|dsd|cda)",
      // font
      "**/*.(woff2?|eot|ttf|otf|ttc|pfa|pfb|pfm|afm)",
      // text
      "**/*.(json|json5|jsonc|txt|text|tsx|jsx|md|mdx|mdc|markdown|yaml|yml|toml)"
    ], {
      cwd: dir,
      onlyFiles: true,
      ignore: [
        "**/node_modules/**",
        "**/dist/**",
        "**/package-lock.*",
        "**/pnpm-lock.*",
        "**/pnpm-workspace.*"
      ]
    });
    cache = await Promise.all(files.map(async (path) => {
      const filePath = (0, import_pathe.resolve)(dir, path);
      const stat = await import_promises.default.lstat(filePath);
      path = path.startsWith("public/") ? path.slice(7) : path;
      return {
        path,
        publicPath: (0, import_pathe.join)(baseURL, path),
        filePath,
        type: guessType(path),
        size: stat.size,
        mtime: stat.mtimeMs
      };
    }));
    return cache;
  }
  function watchAssets() {
    const debouncedAssetsUpdated = (0, import_perfect_debounce.debounce)(() => {
      getRpcServer().assetsUpdated();
    }, 100);
    server.watcher.on("all", (event) => {
      if (event !== "change")
        debouncedAssetsUpdated();
    });
  }
  watchAssets();
  return {
    async getStaticAssets() {
      return await scan();
    },
    async getImageMeta(filepath) {
      if (_imageMetaCache.has(filepath))
        return _imageMetaCache.get(filepath);
      try {
        const meta = (0, import_image_meta.imageMeta)(await import_promises.default.readFile(filepath));
        _imageMetaCache.set(filepath, meta);
        return meta;
      } catch (e) {
        _imageMetaCache.set(filepath, void 0);
        console.error(e);
        return void 0;
      }
    },
    async getTextAssetContent(filepath, limit = 300) {
      try {
        const content = await import_promises.default.readFile(filepath, "utf-8");
        return content.slice(0, limit);
      } catch (e) {
        console.error(e);
        return void 0;
      }
    },
    assetsUpdated() {
    }
  };
}

// src/vite-rpc/graph.ts
var import_perfect_debounce2 = require("perfect-debounce");
function setupGraphRPC(options) {
  const { rpc, server, getRpcServer } = options;
  const debouncedModuleUpdated = (0, import_perfect_debounce2.debounce)(() => {
    getRpcServer().moduleUpdated();
  }, 100);
  server.middlewares.use((req, res, next) => {
    debouncedModuleUpdated();
    next();
  });
  return {
    async getGraph() {
      const list = await rpc.list();
      const modules = (list == null ? void 0 : list.modules) || [];
      return modules;
    },
    moduleUpdated: () => {
    }
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  setupAssetsRPC,
  setupGraphRPC
});
