type AssetType = 'image' | 'font' | 'video' | 'audio' | 'text' | 'json' | 'other';
interface AssetInfo {
    path: string;
    type: AssetType;
    publicPath: string;
    filePath: string;
    size: number;
    mtime: number;
}
interface ImageMeta {
    width: number;
    height: number;
    orientation?: number;
    type?: string;
    mimeType?: string;
}
interface AssetEntry {
    path: string;
    content: string;
    encoding?: BufferEncoding;
    override?: boolean;
}
interface CodeSnippet {
    code: string;
    lang: string;
    name: string;
    docs?: string;
}
interface ModuleInfo {
    id: string;
    plugins: {
        name: string;
        transform?: number;
        resolveId?: number;
    }[];
    deps: string[];
    virtual: boolean;
}
interface ViteRPCFunctions {
    root: () => string;
    getGraph: () => Promise<ModuleInfo[]>;
    getStaticAssets: () => Promise<AssetInfo[]>;
    getImageMeta: (filepath: string) => Promise<ImageMeta | undefined>;
    getTextAssetContent: (filepath: string, limit?: number) => Promise<string | undefined>;
    moduleUpdated: () => void;
    assetsUpdated: () => void;
}

export type { AssetInfo as A, CodeSnippet as C, ImageMeta as I, ModuleInfo as M, ViteRPCFunctions as V, AssetType as a, AssetEntry as b };
